import { Component, forwardRef, Injector, Input, NgModule, Renderer2, HostListener, ChangeDetectorRef, Inject, ViewContainerRef, NgZone, ViewChild } from '@angular/core';
import { TranslateModule, TranslateService } from '@ngx-translate/core';
import { NarikAutoComplete, NarikButton, BUTTON_DEFAULT_OPTIONS, NarikCheckBox, NarikCheckBoxList, NarikDataTable, NarikDatePicker, NarikInput, NarikRadioGroup, NarikSelect, NarikDynamicForm, NarikTreeview, NarikToolBar, NarikTabOutlet } from '@narik/ui-core';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { debounceTime, distinctUntilChanged, map, tap, switchMap, finalize, take } from 'rxjs/operators';
import { of } from 'rxjs';
import { DataProviderService, MODULE_DATA_KEY, PARAMETERS, DIALOG_CONTAINER, DIALOG_MESSAGE_COMPONENT, DIALOG_INPUT_COMPONENT } from '@narik/infrastructure';
import { NgbTypeaheadModule, NgbTooltipModule, NgbDatepickerModule, NgbDateAdapter, NgbDateNativeAdapter, NgbNavModule } from '@ng-bootstrap/ng-bootstrap';
import { CommonModule, DOCUMENT } from '@angular/common';
import { BusyIndicator, NarikListForm, NarikEditForm } from '@narik/app-core';
import { NarikCommonModule, groupBy } from '@narik/common';
import { __decorate, __metadata } from 'tslib';
import { NarikInject, NarikDialogContainer, DialogAnimationBody } from '@narik/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { trigger } from '@angular/animations';
import { UUID } from 'angular2-uuid';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/input-output-items.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const NARIK_UI_COMPONENT_INPUTS = ["options"];
/** @type {?} */
const NARIK_UI_FORM_INPUTS = [
    "id",
    "name",
    "label",
    "disabled",
    "required",
    "readOnly",
    "placeHolder",
    ...NARIK_UI_COMPONENT_INPUTS
];
/** @type {?} */
const NARIK_DATA_ORIENTED_OUTPUTS = [
    "dataChange",
    "selectedItemChange"
];
/** @type {?} */
const NARIK_DATA_ORIENTED_INPUTS = [
    "listenForDataChange",
    "dataSource",
    "dataKey",
    "dataUrl",
    "dataInfo",
    "dataProviderKey",
    "dataParameters",
    "moduleKey",
    "dataMethod",
    "dataUrlMethod",
    ...NARIK_UI_FORM_INPUTS
];
/** @type {?} */
const NARIK_DATA_DISPLAY_VALUE_OUTPUTS = [
    ...NARIK_DATA_ORIENTED_OUTPUTS
];
/** @type {?} */
const NARIK_DATA_DISPLAY_VALUE_INPUTS = [
    "displayField",
    "valueField",
    ...NARIK_DATA_ORIENTED_INPUTS
];
/** @type {?} */
const NARIK_AUTOCOMPLETE_INPUTS = [
    "displayText",
    "minSearchLength",
    "isLazyLoadData"
];
/** @type {?} */
const NARIK_CHECKBOX_INPUTS = ["tag", ...NARIK_UI_FORM_INPUTS];
/** @type {?} */
const NARIK_SELECT_INPUTS = ["multiple"];
/** @type {?} */
const NARIK_DATA_TABLE_SELECT_INPUTS = [
    ...NARIK_SELECT_INPUTS,
    "gridOptions"
];
/** @type {?} */
const NARIK_DATE_PICKER_INPUTS = [...NARIK_UI_FORM_INPUTS];
/** @type {?} */
const NARIK_INPUT_INPUTS = [
    "maxlength",
    "type",
    "mask",
    "icon",
    "displayStatus",
    ...NARIK_UI_FORM_INPUTS
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-auto-complete/narik-ngb-auto-complete.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbAutoComplete extends NarikAutoComplete {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.internalChange = false;
        this.optionData = [];
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set displayValue(value) {
        if (this._displayValue !== value) {
            if (!this.internalChange) {
                this.setValue(value);
            }
            this._displayValue = value;
        }
    }
    /**
     * @return {?}
     */
    get displayValue() {
        return this._displayValue;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.loadDataOnInit = !this.isLazyLoadData;
        super.ngOnInit();
        if (!this.isLazyLoadData) {
            this.search = (/**
             * @param {?} text$
             * @return {?}
             */
            (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), map((/**
             * @param {?} term
             * @return {?}
             */
            (term) => term.length < this.minSearchLength
                ? []
                : this.optionData
                    .filter((/**
                 * @param {?} v
                 * @return {?}
                 */
                v => this.displayField
                    ? v[this.displayField]
                    : v.toLowerCase().indexOf(term.toLowerCase()) > -1))
                    .map((/**
                 * @param {?} v
                 * @return {?}
                 */
                v => (this.displayField ? v[this.displayField] : v)))
                    .slice(0, 10)))));
        }
        else {
            /** @type {?} */
            const dataProviderService = this.injector.get(DataProviderService);
            /** @type {?} */
            const dataInfo = this.createDataInfo();
            dataInfo.dataMethod = "POST";
            dataInfo.actionType = "COMPLETE";
            if (!dataInfo.moduleKey) {
                dataInfo.moduleKey = this.injector.get(MODULE_DATA_KEY);
            }
            this.search = (/**
             * @param {?} text$
             * @return {?}
             */
            (text$) => text$.pipe(debounceTime(200), distinctUntilChanged(), tap((/**
             * @param {?} filter
             * @return {?}
             */
            filter => {
                if (filter && filter.length >= this.minSearchLength) {
                    this.dataIsLoading = true;
                }
            })), switchMap((/**
             * @param {?} filter
             * @return {?}
             */
            filter => {
                dataInfo.dataParameters = {
                    filter: filter
                };
                return filter && filter.length >= this.minSearchLength
                    ? dataProviderService.getData(dataInfo).pipe(tap((/**
                     * @param {?} result
                     * @return {?}
                     */
                    (result) => (this.optionData = result))), finalize((/**
                     * @return {?}
                     */
                    () => (this.dataIsLoading = false))))
                    : of([]);
            }))));
        }
    }
    /**
     * @param {?} selectedText
     * @return {?}
     */
    setValue(selectedText) {
        this.internalChange = true;
        if (!this.displayField) {
            this.value = selectedText;
        }
        else {
            if (selectedText) {
                /** @type {?} */
                const item = this.optionData.filter((/**
                 * @param {?} x
                 * @return {?}
                 */
                x => x[this.displayField] === selectedText))[0];
                if (item) {
                    this.value = item[this.valueField];
                }
                else {
                    this.value = undefined;
                }
            }
            else {
                this.value = undefined;
            }
        }
        this.internalChange = false;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.optionData = data;
    }
    /**
     * @return {?}
     */
    setDisplayText() {
        this.internalChange = true;
        if (this.value) {
            /** @type {?} */
            const item = this.optionData.filter((/**
             * @param {?} x
             * @return {?}
             */
            x => x[this.valueField] === this.value))[0];
            this.displayValue = item ? item[this.displayField] : this.displayText;
        }
        else {
            this.displayValue = "";
        }
        this.internalChange = false;
    }
    /**
     * @protected
     * @param {?} newValue
     * @param {?} oldValue
     * @return {?}
     */
    valueChanged(newValue, oldValue) {
        if (newValue !== oldValue && !this.internalChange) {
            this.setDisplayText();
        }
    }
    /**
     * @return {?}
     */
    onBlur() {
        if (!this.isLazyLoadData) {
            this.setDisplayText();
        }
    }
}
NarikNgbAutoComplete.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-autocomplete  , narik-autocomplete ",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n  <input (blur)=\"onBlur()\" [required]=\"required\" [(ngModel)]=\"displayValue\" [attr.disabled]=\"disabled || null\"\r\n    type=\"text\" name=\"{{name}}\" class=\"form-control\" [ngbTypeahead]=\"search\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\r\n  <input type=\"hidden\" name=\"{{name}}\" [(ngModel)]=\"value\">\r\n</ng-template>",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbAutoComplete)),
                        multi: true
                    }
                ],
                styles: [""]
            }] }
];
/** @nocollapse */
NarikNgbAutoComplete.ctorParameters = () => [
    { type: Injector }
];
NarikNgbAutoComplete.propDecorators = {
    icon: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbAutoComplete.prototype.internalChange;
    /** @type {?} */
    NarikNgbAutoComplete.prototype.optionData;
    /** @type {?} */
    NarikNgbAutoComplete.prototype.search;
    /** @type {?} */
    NarikNgbAutoComplete.prototype._displayValue;
    /** @type {?} */
    NarikNgbAutoComplete.prototype.icon;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-auto-complete/narik-ngb-auto-complete.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbAutoCompleteModule {
}
NarikNgbAutoCompleteModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, NgbTypeaheadModule],
                declarations: [NarikNgbAutoComplete],
                exports: [NarikNgbAutoComplete],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-busy-indicator/narik-ngb-busy-indicator.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbBusyIndicator {
    /**
     * @param {?} newState
     * @param {?=} msg
     * @return {?}
     */
    setBusy(newState, msg) {
        this.isBusy = newState;
    }
}
NarikNgbBusyIndicator.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-busy-indicator , narik-busy-indicator",
                template: "<ng-content></ng-content>\r\n<div class=\"loading-panel\" *ngIf=\"isBusy\"></div>\r\n<div *ngIf=\"isBusy\" id=\"loader-wrapper\">\r\n  <div class=\"spinner-border text-primary\" role=\"status\">\r\n    <span class=\"sr-only\">Loading...</span>\r\n  </div>\r\n</div>\r\n",
                providers: [
                    {
                        provide: BusyIndicator,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbBusyIndicator))
                    }
                ],
                styles: [".loading-panel{background-color:#fff;bottom:0;left:0;opacity:.4;position:absolute;right:0;top:0;width:100%;z-index:50000}#loader-wrapper{height:64px;left:50%;margin-left:-20px;margin-top:-20px;position:absolute;top:50%;width:64px;z-index:1000}"]
            }] }
];
NarikNgbBusyIndicator.propDecorators = {
    isBusy: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbBusyIndicator.prototype.busyMessage;
    /** @type {?} */
    NarikNgbBusyIndicator.prototype.isBusy;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-busy-indicator/narik-ngb-busy-indicator.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbBusyIndicatorModule {
}
NarikNgbBusyIndicatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, TranslateModule],
                declarations: [NarikNgbBusyIndicator],
                exports: [NarikNgbBusyIndicator],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-button/narik-ngb-button.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbButtonComponent extends NarikButton {
    /**
     * @param {?} renderer
     * @param {?} injector
     */
    constructor(renderer, injector) {
        super(injector);
        this.renderer = renderer;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onClick(event) {
        event.stopPropagation();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        this.buttonStyle = this.buttonStyle || this.defaultOptions.buttonStyle;
        this.busyFontIcon = this.busyFontIcon || this.defaultOptions.busyFontIcon;
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @param {?} e
     * @return {?}
     */
    buttonClick(e) {
        if (!this.disable && !this.isBusy) {
            this.nClick.emit({
                sender: this,
                event: e
            });
        }
    }
}
NarikNgbButtonComponent.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-button , narik-button ",
                template: "<button\r\n  ngbTooltip=\"{{(tooltip ?  (tooltip | translate) : '') + ( options.appendShortcutToTooltip && shortcut ? '(' + (shortcut | shortcut) +')' : '' )}}\"\r\n  container=\"body\"\r\n  placement=\"bottom\" (click)=\"buttonClick($event)\" [disabled]=\"disable || isBusy\" class=\"btn btn-{{buttonStyle}}\"\r\n  type=\"button\" [ngClass]='cssClass'>\r\n  <span *ngIf=\"isBusy\" class=\"mx-1 spinner-border spinner-border-sm\" role=\"status\" aria-hidden=\"true\"></span>\r\n  <i *ngIf=\"icon\" class=\"fa fa-{{icon}}\"></i>\r\n  {{ isBusy && busyLabel ? busyLabel : label}}\r\n</button>"
            }] }
];
/** @nocollapse */
NarikNgbButtonComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: Injector }
];
NarikNgbButtonComponent.propDecorators = {
    onClick: [{ type: HostListener, args: ["click", ["$event"],] }]
};
__decorate([
    NarikInject(BUTTON_DEFAULT_OPTIONS, {
        buttonStyle: "secondary",
        busyFontIcon: "fa-spinner"
    }),
    __metadata("design:type", Object)
], NarikNgbButtonComponent.prototype, "defaultOptions", void 0);
if (false) {
    /** @type {?} */
    NarikNgbButtonComponent.prototype.defaultOptions;
    /**
     * @type {?}
     * @private
     */
    NarikNgbButtonComponent.prototype.renderer;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-button/narik-ngb-button.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbButtonModule {
}
NarikNgbButtonModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, NgbTooltipModule, TranslateModule, NarikCommonModule],
                declarations: [NarikNgbButtonComponent],
                exports: [NarikNgbButtonComponent],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box/narik-ngb-checkbox.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBox extends NarikCheckBox {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
}
NarikNgbCheckBox.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-checkbox , narik-checkbox",
                template: "<div class=\"form-check\">\r\n  <input [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"checkbox\"\r\n  [(ngModel)]=\"value\" id=\"{{id}}\">\r\n  <label class=\"form-check-label\" for=\"{{id}}\">\r\n    {{label}}\r\n  </label>\r\n</div>\r\n",
                inputs: [...NARIK_CHECKBOX_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBox)),
                        multi: true
                    },
                    {
                        provide: NarikCheckBox,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBox))
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbCheckBox.ctorParameters = () => [
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box/narik-ngb-checkbox.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxModule {
}
NarikNgbCheckBoxModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbCheckBox],
                exports: [NarikNgbCheckBox],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box-list/narik-ngb-checkbox-list.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxList extends NarikCheckBoxList {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = "vertical";
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    /**
     * @return {?}
     */
    get layoutDirection() {
        return this._layoutDirection;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.itemsData = data;
    }
}
NarikNgbCheckBoxList.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-checkbox-list , narik-checkbox-list",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"form-check-container p-1 pl-2\">\r\n    <div [ngClass]=\"{ 'vertical-content': layoutDirection == 'vertical' }\">\r\n      <narik-checkbox *ngFor=\"let item of itemsData\" (change)=\"addOrRemove(valueField ? item[valueField] : item)\"\r\n        [tag]=\"valueField ? item[valueField] : item\" label=\"{{ item[displayField] }}\">\r\n      </narik-checkbox>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbCheckBoxList)),
                        multi: true
                    }
                ],
                styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}"]
            }] }
];
/** @nocollapse */
NarikNgbCheckBoxList.ctorParameters = () => [
    { type: Injector }
];
NarikNgbCheckBoxList.propDecorators = {
    layoutDirection: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbCheckBoxList.prototype.itemsData;
    /** @type {?} */
    NarikNgbCheckBoxList.prototype._layoutDirection;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box-list/narik-ngb-checkbox-list.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCheckBoxListModule {
}
NarikNgbCheckBoxListModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbCheckBoxModule
                ],
                declarations: [NarikNgbCheckBoxList],
                exports: [NarikNgbCheckBoxList],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-data-table/narik-ngb-data-table.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDataTable extends NarikDataTable {
    /**
     * @param {?} injector
     * @param {?} changeDetector
     * @param {?} document
     */
    constructor(injector, changeDetector, document) {
        super(injector);
        this.changeDetector = changeDetector;
        this.document = document;
    }
}
NarikNgbDataTable.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-data-table , narik-data-table",
                template: ""
            }] }
];
/** @nocollapse */
NarikNgbDataTable.ctorParameters = () => [
    { type: Injector },
    { type: ChangeDetectorRef },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    NarikNgbDataTable.prototype.changeDetector;
    /**
     * @type {?}
     * @private
     */
    NarikNgbDataTable.prototype.document;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-data-table/narik-ngb-data-table.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDataTableModule {
}
NarikNgbDataTableModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, TranslateModule],
                declarations: [NarikNgbDataTable],
                exports: [NarikNgbDataTable],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-date-picker/narik-ngb-date-picker.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDatePicker extends NarikDatePicker {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
}
NarikNgbDatePicker.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-date-picker , narik-date-picker",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n\r\n  <div class=\"input-group\">\r\n    <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\" name=\"dp\"\r\n      [(ngModel)]=\"value\" ngbDatepicker #d=\"ngbDatepicker\">\r\n    <div class=\"input-group-append\">\r\n      <button class=\"btn btn-outline-secondary\" (click)=\"d.toggle()\" type=\"button\">\r\n        <i class=\"fa fa-calendar-alt\" aria-hidden=\"true\"></i>\r\n      </button>\r\n    </div>\r\n  </div>\r\n\r\n</div>\r\n",
                inputs: [...NARIK_DATE_PICKER_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbDatePicker)),
                        multi: true
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbDatePicker.ctorParameters = () => [
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-date-picker/narik-ngb-date-picker.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDatePickerModule {
}
NarikNgbDatePickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule, NgbDatepickerModule, TranslateModule],
                declarations: [NarikNgbDatePicker],
                exports: [NarikNgbDatePicker],
                providers: [{ provide: NgbDateAdapter, useClass: NgbDateNativeAdapter }]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-date-picker/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-input/narik-ngb-input.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInput extends NarikInput {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set icon(value) {
        this._icon = value;
    }
    /**
     * @return {?}
     */
    get icon() {
        return this._icon;
    }
}
NarikNgbInput.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-input , narik-input",
                template: "<div class=\"form-group \">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n  <input [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\" type=\"{{type}}\" name=\"{{name}}\" [required]=\"required\"\r\n    class=\"form-control\" id=\"{{id}}\" placeholder=\"{{placeHolder}}\">\r\n</ng-template>",
                inputs: [...NARIK_INPUT_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbInput)),
                        multi: true
                    }
                ]
            }] }
];
/** @nocollapse */
NarikNgbInput.ctorParameters = () => [
    { type: Injector }
];
NarikNgbInput.propDecorators = {
    icon: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbInput.prototype._icon;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-input/narik-ngb-input.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInputModule {
}
NarikNgbInputModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbInput],
                exports: [NarikNgbInput],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-radio/narik-ngb-radio-group.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbRadioGroup extends NarikRadioGroup {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.itemsData = [];
        this._layoutDirection = "vertical";
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set layoutDirection(value) {
        this._layoutDirection = value;
    }
    /**
     * @return {?}
     */
    get layoutDirection() {
        return this._layoutDirection;
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.itemsData = data;
    }
}
NarikNgbRadioGroup.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-radio-group , narik-radio-group",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"form-check-container p-1 pl-2\">\r\n    <div class=\"form-check \" [ngClass]=\"{'form-check-inline': layoutDirection==='horizontal'}\"\r\n      *ngFor=\"let item of itemsData;let i=index\">\r\n      <input [required]=\"required\" [attr.disabled]=\"disabled || null\" class=\"form-check-input\" type=\"radio\" name=\"{{name}}\" id=\"{{id+i}}\"\r\n        value=\"{{item[valueField]}}\" checked>\r\n      <label class=\"form-check-label\" for=\"{{id+i}}\">\r\n        {{item[displayField]}}\r\n      </label>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbRadioGroup)),
                        multi: true
                    }
                ],
                styles: [".form-check-container{border:1px solid #ced4da;border-radius:.25rem}"]
            }] }
];
/** @nocollapse */
NarikNgbRadioGroup.ctorParameters = () => [
    { type: Injector }
];
NarikNgbRadioGroup.propDecorators = {
    layoutDirection: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbRadioGroup.prototype.itemsData;
    /** @type {?} */
    NarikNgbRadioGroup.prototype._layoutDirection;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-radio/narik-ngb-radio.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbRadioGroupModule {
}
NarikNgbRadioGroupModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbRadioGroup],
                exports: [NarikNgbRadioGroup],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-select/narik-ngb-select.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbSelect extends NarikSelect {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.optionData = [];
    }
    /**
     * @protected
     * @param {?} data
     * @return {?}
     */
    useData(data) {
        this.optionData = data;
    }
}
NarikNgbSelect.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-select , narik-select",
                template: "<div class=\"form-group\">\r\n  <label for=\"{{id}}\">{{label}}</label>\r\n  <div class=\"input-group mb-3\" *ngIf=\"icon\">\r\n    <div class=\"input-group-prepend\">\r\n      <span class=\"input-group-text\"><i class=\"fa fa-{{icon}}\"></i></span>\r\n    </div>\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </div>\r\n  <ng-container *ngIf=\"!icon\">\r\n    <ng-container *ngTemplateOutlet=\"inputElement\"></ng-container>\r\n  </ng-container>\r\n\r\n</div>\r\n<ng-template #inputElement>\r\n\r\n  <select [required]=\"required\" class=\"custom-select\" [(ngModel)]=\"value\" [attr.disabled]=\"disabled || null\"\r\n    id=\"{{id}}\">\r\n    <option *ngFor=\"let item of optionData\" [value]=\"item[valueField]\">{{item[displayField]}}</option>\r\n  </select>\r\n\r\n\r\n\r\n</ng-template>",
                inputs: [...NARIK_DATA_DISPLAY_VALUE_INPUTS, ...NARIK_SELECT_INPUTS],
                outputs: [...NARIK_DATA_DISPLAY_VALUE_OUTPUTS],
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbSelect)),
                        multi: true
                    }
                ],
                styles: [".select-clear{left:-2px;position:absolute;top:-30px}.search-input{box-sizing:border-box;padding:16px}.search-continer{background-color:#fff;border-bottom:1px solid rgba(0,0,0,.12);position:-webkit-sticky;position:sticky;top:0;width:100%;z-index:10000}"]
            }] }
];
/** @nocollapse */
NarikNgbSelect.ctorParameters = () => [
    { type: Injector }
];
NarikNgbSelect.propDecorators = {
    icon: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbSelect.prototype.optionData;
    /** @type {?} */
    NarikNgbSelect.prototype.icon;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-select/narik-ngb-select.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbSelectModule {
}
NarikNgbSelectModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [NarikNgbSelect],
                exports: [NarikNgbSelect],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dynamic-form/narik-ngb-dynamic-form.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDynamicForm extends NarikDynamicForm {
    /**
     * @param {?} injector
     * @param {?} viewContainerRef
     */
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.columnWidth = 100;
        this.fieldsArray = new Map();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        if (this.columnsCount === 1) {
            this.layoutGap = 0;
        }
        if (this.groupFields) {
            /** @type {?} */
            const data = groupBy(this.fields, 'options.groupIndex');
            data.forEach((/**
             * @param {?} x
             * @return {?}
             */
            (x) => this.fieldsArray.set(x.key && x.key !== 'undefined' ? +x.key : 0, x.value)));
            this.groupCount =
                Math.max(...this.fieldsArray.entriesArray().map((/**
                 * @param {?} x
                 * @return {?}
                 */
                (x) => x.key))) + 1;
        }
        this.columnWidth = 100 / this.columnsCount;
    }
}
NarikNgbDynamicForm.decorators = [
    { type: Component, args: [{
                selector: 'narik-dynamic-form , narik-ngb-dynamic-form',
                template: "<div\r\n  [tab-guard]=\"activeTabGuard\"\r\n  [auto-focus]=\"activeAutoFocus\"\r\n  [autoFocusContainerName]=\"defaultFocusField\"\r\n  fxLayout=\"{{ columnsCount === 1 ? 'column' : 'row wrap' }} \"\r\n  fxLayout.xs=\"column\"\r\n  fxLayoutGap.xs=\"0\"\r\n  fxLayoutGap=\"{{ layoutGap }}px\"\r\n  fxLayoutAlign=\"flex-start\"\r\n>\r\n  <ng-container *ngIf=\"!groupFields\">\r\n    <div\r\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\r\n      fxFlex=\"100%\"\r\n      *ngFor=\"let item of fields; let i = index\"\r\n    >\r\n      <ng-container\r\n        *ngTemplateOutlet=\"\r\n          fieldContainer;\r\n          context: {\r\n            $implicit: item,\r\n            invisibleItems: invisibleItems,\r\n            disableItems: disableItems,\r\n            model: model,\r\n            form: form\r\n          }\r\n        \"\r\n      ></ng-container>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"groupFields\">\r\n    <div\r\n      fxFlex.gt-xs=\"0 1 calc({{ columnWidth }}% - {{ layoutGap }}px)\"\r\n      fxFlex=\"100%\"\r\n      *ngFor=\"let item of [].constructor(groupCount); let i = index\"\r\n    >\r\n      <div fxLayout=\"column\" class=\"narik-form-group\">\r\n        <div *ngFor=\"let item of fieldsArray.get(i); let j = index\">\r\n          <ng-container\r\n            *ngTemplateOutlet=\"\r\n              fieldContainer;\r\n              context: {\r\n                $implicit: item,\r\n                invisibleItems: invisibleItems,\r\n                disableItems: disableItems,\r\n                model: model,\r\n                form: form\r\n              }\r\n            \"\r\n          ></ng-container>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </ng-container>\r\n</div>\r\n\r\n<ng-template\r\n  #fieldContainer\r\n  let-item\r\n  let-invisibleItems=\"invisibleItems\"\r\n  let-model=\"model\"\r\n  let-form=\"form\"\r\n  let-disableItems=\"disableItems\"\r\n>\r\n  <ng-container\r\n    [formGroup]=\"form\"\r\n    *ngIf=\"!item.hideExpr || !invisibleItems[item.name]\"\r\n  >\r\n    <ng-container *ngIf=\"!customFormComponentKeysObject[item.type || 'text']\">\r\n      <ng-container\r\n        *ngIf=\"\r\n          !item.type ||\r\n          item.type == 'text' ||\r\n          item.type == 'number' ||\r\n          item.type == 'time' ||\r\n          item.type == 'textArea' ||\r\n          item.type == 'password'\r\n        \"\r\n      >\r\n        <narik-input\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [type]=\"item.type || 'text'\"\r\n          label=\"{{ item.label | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n          [options]=\"item.options\"\r\n        >\r\n        </narik-input>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'boolean'\">\r\n        <narik-checkbox\r\n          [name]=\"item.name\"\r\n          [options]=\"item.options\"\r\n          [formControlName]=\"item.model\"\r\n          label=\"{{ item.label | translate }}\"\r\n        >\r\n        </narik-checkbox>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'date'\">\r\n        <narik-date-picker\r\n          [options]=\"item.options\"\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n          label=\"{{ item.label | translate }}\"\r\n        ></narik-date-picker>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'select'\">\r\n        <narik-select\r\n          [options]=\"item.options\"\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [dataInfo]=\"item.dataInfo\"\r\n          label=\"{{ item.label | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n        ></narik-select>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'autoComplete'\">\r\n        <narik-autocomplete\r\n          [options]=\"item.options\"\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [minSearchLength]=\"item.options.minSearchLength || 0\"\r\n          [isLazyLoadData]=\"item.options.isLazyLoadData\"\r\n          [dataInfo]=\"item.dataInfo\"\r\n          label=\"{{ item.label | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n        ></narik-autocomplete>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'radio'\">\r\n        <narik-radio-group\r\n          [options]=\"item.options\"\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [dataInfo]=\"item.dataInfo\"\r\n          label=\"{{ item.label | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n        ></narik-radio-group>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'checkList'\">\r\n        <narik-checkbox-list\r\n          [options]=\"item.options\"\r\n          [name]=\"item.name\"\r\n          [required]=\"item.required\"\r\n          placeHolder=\"{{ item.options.placeHolder | translate }}\"\r\n          [dataInfo]=\"item.dataInfo\"\r\n          label=\"{{ item.label | translate }}\"\r\n          [formControlName]=\"item.model\"\r\n        ></narik-checkbox-list>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"item.type == 'table-select'\"> </ng-container>\r\n    </ng-container>\r\n    <ng-container *ngIf=\"customFormComponentKeysObject[item.type || 'text']\">\r\n      <ng-container\r\n        *narikComponentLoader=\"\r\n          customFormComponentKeysObject[item.type || 'text'];\r\n          bindings: {\r\n            field: item,\r\n            model: model\r\n          };\r\n          bindingSource: this;\r\n          parameters: {\r\n            form: form\r\n          }\r\n        \"\r\n      ></ng-container>\r\n    </ng-container>\r\n  </ng-container>\r\n</ng-template>\r\n",
                providers: [
                    {
                        provide: NarikDynamicForm,
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => NarikNgbDynamicForm)),
                    },
                ]
            }] }
];
/** @nocollapse */
NarikNgbDynamicForm.ctorParameters = () => [
    { type: Injector },
    { type: ViewContainerRef }
];
if (false) {
    /** @type {?} */
    NarikNgbDynamicForm.prototype.columnWidth;
    /** @type {?} */
    NarikNgbDynamicForm.prototype.groupCount;
    /** @type {?} */
    NarikNgbDynamicForm.prototype.fieldsArray;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dynamic-form/narik-ngb-dynamic-form.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDynamicFormModule {
}
NarikNgbDynamicFormModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    TranslateModule,
                    NarikNgbInputModule,
                    NarikNgbSelectModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbDatePickerModule,
                    NarikNgbCheckBoxListModule,
                    NarikCommonModule,
                    FlexLayoutModule,
                ],
                declarations: [NarikNgbDynamicForm],
                exports: [NarikNgbDynamicForm],
                providers: [],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dialog/narik-ngb-dialog-container.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbDialogContainer extends NarikDialogContainer {
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbDialogContainer.decorators = [
    { type: Component, args: [{
                template: "<div\r\n  [@openClose]=\"isOpen ? 'open' : 'closed'\"\r\n  [class]=\"options.dialogCssClass\"\r\n  (@openClose.done)=\"_onAnimationDone($event)\"\r\n  class=\"modal-content\"\r\n  cdkDrag\r\n  [tab-guard]=\"true\"\r\n>\r\n  <div class=\"modal-header\">\r\n    <h5 cdkDragHandle class=\"modal-title\">{{ title | translate }}</h5>\r\n  </div>\r\n\r\n  <div class=\"modal-body\">\r\n    <ng-template narik-loader-host></ng-template>\r\n  </div>\r\n\r\n  <div\r\n    class=\"modal-footer\"\r\n    [auto-focus]=\"true\"\r\n    [autoFocusContainerName]=\"options.defaultAction\"\r\n    *ngIf=\"actions && actions.length !== 0\"\r\n    align=\"end\"\r\n  >\r\n    <ng-container *ngFor=\"let item of actions\">\r\n      <ng-container>\r\n        <narik-button\r\n          cssClass=\"btn-sm\"\r\n          [attr.narik-form-item-key]=\"item.dialogResult\"\r\n          class=\"mr-2\"\r\n          (nClick)=\"actionClick(item)\"\r\n          [color]=\"item.color\"\r\n          [icon]=\"item.icon\"\r\n          label=\"{{ 'dialog-buttons.' + item.label | translate }}\"\r\n        ></narik-button>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n",
                animations: [trigger("openClose", DialogAnimationBody)],
                styles: [".dialog-container{background-color:#fff;border-radius:5px;box-shadow:20px 20px 15px -7px rgba(0,0,0,.2),0 24px 38px 3px rgba(0,0,0,.14),0 9px 46px 8px rgba(0,0,0,.12)}"]
            }] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dialog/narik-ngb-input-dialog.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbInputDialog {
    /**
     * @param {?} parameters
     */
    constructor(parameters) {
        this.entity = {};
        this.fields = [];
        if (parameters) {
            this.entity = parameters.entity;
            this.fields = parameters.fields;
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbInputDialog.decorators = [
    { type: Component, args: [{
                template: "<div class=\"pr-2 pl-2\">\r\n  <narik-dynamic-form [model]=\"entity\" [fields]=\"fields\"></narik-dynamic-form>\r\n</div>\r\n"
            }] }
];
/** @nocollapse */
NarikNgbInputDialog.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [PARAMETERS,] }] }
];
if (false) {
    /** @type {?} */
    NarikNgbInputDialog.prototype.entity;
    /** @type {?} */
    NarikNgbInputDialog.prototype.fields;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dialog/narik-ngb-message-dialog.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbMessageDialog {
    /**
     * @param {?} parameters
     */
    constructor(parameters) {
        if (parameters) {
            this.message = parameters.message;
        }
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NarikNgbMessageDialog.decorators = [
    { type: Component, args: [{
                template: "<div class=\"message-container\">{{message | translate}}</div>\r\n",
                styles: [""]
            }] }
];
/** @nocollapse */
NarikNgbMessageDialog.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [PARAMETERS,] }] }
];
if (false) {
    /** @type {?} */
    NarikNgbMessageDialog.prototype.message;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dialog/narik-ngb-dialog.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
const ɵ0 = NarikNgbDialogContainer, ɵ1 = NarikNgbMessageDialog, ɵ2 = NarikNgbInputDialog;
class NarikNgbDialogModule {
}
NarikNgbDialogModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    TranslateModule,
                    NarikCommonModule,
                    NarikNgbButtonModule,
                    NarikNgbDynamicFormModule
                ],
                declarations: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ],
                exports: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ],
                providers: [
                    {
                        provide: DIALOG_CONTAINER,
                        useValue: ɵ0
                    },
                    {
                        provide: DIALOG_MESSAGE_COMPONENT,
                        useValue: ɵ1
                    },
                    {
                        provide: DIALOG_INPUT_COMPONENT,
                        useValue: ɵ2
                    }
                ],
                entryComponents: [
                    NarikNgbDialogContainer,
                    NarikNgbInputDialog,
                    NarikNgbMessageDialog
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-treeview/narik-ngb-treeview.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTreeview extends NarikTreeview {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set selectedItem(value) {
        this._selectedItem = value;
    }
    /**
     * @return {?}
     */
    get selectedItem() {
        return this._selectedItem;
    }
    /**
     * @param {?} selectedNode
     * @return {?}
     */
    addNode(selectedNode) {
        throw new Error("Method not implemented.");
    }
    /**
     * @param {?} selectedNode
     * @return {?}
     */
    deleteNode(selectedNode) {
        throw new Error("Method not implemented.");
    }
}
NarikNgbTreeview.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-treeview narik-treeview",
                template: ""
            }] }
];
/** @nocollapse */
NarikNgbTreeview.ctorParameters = () => [
    { type: Injector }
];
NarikNgbTreeview.propDecorators = {
    newNodeTitle: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    NarikNgbTreeview.prototype.newNodeTitle;
    /** @type {?} */
    NarikNgbTreeview.prototype._selectedItem;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-toolbar/narik-ngb-toolbar.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbToolBar extends NarikToolBar {
    /**
     * @param {?} injector
     * @param {?} viewContainerRef
     */
    constructor(injector, viewContainerRef) {
        super(injector, viewContainerRef);
        this.uniqueId = "";
        this.toolbarItems = [];
        this.uniqueId = "toolbar" + UUID.UUID();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        /** @type {?} */
        let isnewGroup = false;
        /** @type {?} */
        let toolBarGroup = [];
        for (const item of this.items) {
            if (item.itemType === "divider") {
                isnewGroup = true;
            }
            if (item.itemType !== "divider") {
                toolBarGroup.push(item);
            }
            if (isnewGroup) {
                this.toolbarItems.push([...toolBarGroup]);
                toolBarGroup = [];
            }
            isnewGroup = false;
        }
        if (toolBarGroup.length !== 0) {
            this.toolbarItems.push(toolBarGroup);
        }
        for (const group of this.toolbarItems) {
            /** @type {?} */
            let index = 0;
            for (const item of group) {
                /** @type {?} */
                let cssClass = "";
                if (index !== 0) {
                    cssClass += " btn-not-first-child";
                }
                if (index !== group.length - 1) {
                    cssClass += " btn-not-last-child";
                }
                item.cssClass = (item.cssClass || "") + cssClass;
                index++;
            }
        }
    }
}
NarikNgbToolBar.decorators = [
    { type: Component, args: [{
                selector: "narik-toolbar , narik-ngb-toolbar",
                template: "<div class=\"btn-toolbar\" role=\"toolbar\" aria-label=\"Toolbar with button groups\">\r\n  <div class=\"btn-group mr-1\" *ngFor=\"let group of toolbarItems\">\r\n    <ng-container *ngFor=\"let item of group; let i = index\">\r\n      <ng-container *ngIf=\"item.itemType === 'button'\">\r\n        <narik-button\r\n          class=\"toolbar-btn\"\r\n          *ngIf=\"!item.hideExpr || !invisibleItems[item.key]\"\r\n          [disable]=\"item.disableExpr && disableItems[item.key]\"\r\n          [isBusy]=\"item.busyExpr && busyItems[item.key]\"\r\n          [cssClass]=\"item.cssClass\"\r\n          (nClick)=\"itemCommand(item)\"\r\n          [buttonStyle]=\"'secondary'\"\r\n          [icon]=\"item.icon\"\r\n          ngbTooltip=\"{{\r\n            (item.tooltip ? (item.tooltip | translate) : '') +\r\n              (options.appendShortcutToTooltip && item.shortcut\r\n                ? '(' + (item.shortcut | shortcut) + ')'\r\n                : '')\r\n          }}\"\r\n          container=\"body\"\r\n          [label]=\"showLabel ? item.label : ''\"\r\n        ></narik-button>\r\n      </ng-container>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n"
            }] }
];
/** @nocollapse */
NarikNgbToolBar.ctorParameters = () => [
    { type: Injector },
    { type: ViewContainerRef }
];
if (false) {
    /** @type {?} */
    NarikNgbToolBar.prototype.uniqueId;
    /** @type {?} */
    NarikNgbToolBar.prototype.toolbarItems;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-toolbar/narik-ngb-toolbar.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbToolbarModule {
}
NarikNgbToolbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbButtonModule,
                    TranslateModule,
                    NgbTooltipModule,
                    NarikCommonModule
                ],
                declarations: [NarikNgbToolBar],
                exports: [NarikNgbToolBar],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-treeview/narik-ngb-treeview.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTreeviewModule {
}
NarikNgbTreeviewModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    NarikNgbToolbarModule,
                    TranslateModule
                ],
                declarations: [NarikNgbTreeview],
                exports: [NarikNgbTreeview],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-core/narik-ngb-core.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbCoreModule {
}
NarikNgbCoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [],
                exports: [],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-tab-outlet/narik-ngb-tab-outlet.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTabOutlet extends NarikTabOutlet {
    /**
     * @param {?} injector
     * @param {?} zone
     */
    constructor(injector, zone) {
        super(injector);
        this.zone = zone;
    }
    /**
     * @param {?} index
     * @return {?}
     */
    removeTabItem(index) {
        this.removeTab(index);
        return false;
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    addView(tab) {
        super.addView(tab);
        this.zone.onStable
            .pipe(take(1))
            .subscribe((/**
         * @return {?}
         */
        () => this.navElement.select(tab.uniqueId)));
    }
}
NarikNgbTabOutlet.decorators = [
    { type: Component, args: [{
                selector: "narik-ngb-tab-outlet , narik-tab-outlet",
                template: "<div>\r\n  <nav ngbNav #nav=\"ngbNav\" [destroyOnHide]=\"false\" class=\"nav-tabs\">\r\n    <ng-container\r\n      ngbNavItem=\"tab.uniqueId\"\r\n      *ngFor=\"let tab of tabs; let index = index; trackBy: trackByFn\"\r\n    >\r\n      <ng-template ngbNavContent>\r\n        <div class=\"p-1\">\r\n          <ng-container *ngIf=\"tab.component\">\r\n            <ng-container\r\n              *narikComponentLoader=\"\r\n                tab.component;\r\n                parameters: tab.data;\r\n                providers: tab.providers\r\n              \"\r\n            ></ng-container>\r\n          </ng-container>\r\n        </div>\r\n      </ng-template>\r\n      <ng-template ngbNavLink>\r\n        <div class=\"title-container\">\r\n          <span>{{ tab.title | translate }}</span>\r\n          <i (click)=\"removeTabItem(index)\" class=\"fas fa-times close-btn ml-2\">\r\n          </i>\r\n        </div>\r\n      </ng-template>\r\n    </ng-container>\r\n  </nav>\r\n</div>\r\n",
                styles: [".close-btn{color:red;cursor:pointer}.title-container{display:\"flex\";justify-content:space-between}"]
            }] }
];
/** @nocollapse */
NarikNgbTabOutlet.ctorParameters = () => [
    { type: Injector },
    { type: NgZone }
];
NarikNgbTabOutlet.propDecorators = {
    navElement: [{ type: ViewChild, args: ["nav", { static: true },] }]
};
if (false) {
    /** @type {?} */
    NarikNgbTabOutlet.prototype.navElement;
    /**
     * @type {?}
     * @private
     */
    NarikNgbTabOutlet.prototype.zone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-tab-outlet/narik-ngb-tab-outlet.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikNgbTabOutletModule {
}
NarikNgbTabOutletModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, TranslateModule, NarikCommonModule, NgbNavModule],
                declarations: [NarikNgbTabOutlet],
                exports: [NarikNgbTabOutlet],
                providers: [],
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ui-ng-bootstrap.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NarikUiNgBootstrapModule {
}
NarikUiNgBootstrapModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    TranslateModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbBusyIndicatorModule,
                    NarikNgbButtonModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbCheckBoxListModule,
                    NarikNgbDataTableModule,
                    NarikNgbDatePickerModule,
                    NarikNgbDialogModule,
                    NarikNgbDynamicFormModule,
                    NarikNgbInputModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbSelectModule,
                    NarikNgbToolbarModule,
                    NarikNgbTreeviewModule,
                    NarikNgbCoreModule,
                    NarikNgbTabOutletModule
                ],
                declarations: [],
                exports: [
                    TranslateModule,
                    NarikNgbAutoCompleteModule,
                    NarikNgbBusyIndicatorModule,
                    NarikNgbButtonModule,
                    NarikNgbCheckBoxModule,
                    NarikNgbCheckBoxListModule,
                    NarikNgbDataTableModule,
                    NarikNgbDatePickerModule,
                    NarikNgbDialogModule,
                    NarikNgbDynamicFormModule,
                    NarikNgbInputModule,
                    NarikNgbRadioGroupModule,
                    NarikNgbSelectModule,
                    NarikNgbToolbarModule,
                    NarikNgbTreeviewModule,
                    NarikNgbCoreModule,
                    NarikNgbTabOutletModule
                ],
                providers: []
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/base/narik-ngb-list-form.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class NarikUiListForm extends NarikListForm {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
        this.ds = [];
        this.hasDataSource = false;
    }
    /**
     * @return {?}
     */
    get isServerSide() {
        return this.config && this.config.isServerSideData ? true : false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        if (this.fields) {
        }
        if (this.config) {
            if (this.isServerSide) {
                /** @type {?} */
                const that = this;
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() { }
    /**
     * @param {?} result
     * @return {?}
     */
    useData(result) {
        this.dataSource = (/** @type {?} */ (result.data));
    }
    /**
     * @protected
     * @param {?=} remoteDaraParams
     * @return {?}
     */
    refresh(remoteDaraParams) {
        if (!this.isServerSide) {
            this.getEntities();
        }
        else {
        }
    }
}
__decorate([
    NarikInject(TranslateService),
    __metadata("design:type", TranslateService)
], NarikUiListForm.prototype, "translateService", void 0);
if (false) {
    /** @type {?} */
    NarikUiListForm.prototype.ds;
    /** @type {?} */
    NarikUiListForm.prototype.translateService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/base/narik-ngb-edit-form.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
class NarikUiEditForm extends NarikEditForm {
    /**
     * @param {?} injector
     */
    constructor(injector) {
        super(injector);
    }
    /**
     * @return {?}
     */
    submit() {
        if (this.formElement) {
            this.renderer.addClass(this.formElement.nativeElement, "was-validated");
        }
        super.submit();
    }
}
__decorate([
    NarikInject(Renderer2),
    __metadata("design:type", Renderer2)
], NarikUiEditForm.prototype, "renderer", void 0);
if (false) {
    /** @type {?} */
    NarikUiEditForm.prototype.renderer;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/base/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-auto-complete/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-busy-indicator/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-button/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-check-box-list/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-input/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-radio/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-select/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-toolbar/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dynamic-form/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-treeview/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-dialog/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-data-table/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-core/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/narik-ngb-tab-outlet/public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: narik-ui-ng-bootstrap.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NarikNgbAutoComplete, NarikNgbAutoCompleteModule, NarikNgbBusyIndicator, NarikNgbBusyIndicatorModule, NarikNgbButtonComponent, NarikNgbButtonModule, NarikNgbCheckBox, NarikNgbCheckBoxList, NarikNgbCheckBoxListModule, NarikNgbCheckBoxModule, NarikNgbCoreModule, NarikNgbDataTable, NarikNgbDataTableModule, NarikNgbDatePicker, NarikNgbDatePickerModule, NarikNgbDialogContainer, NarikNgbDialogModule, NarikNgbDynamicForm, NarikNgbDynamicFormModule, NarikNgbInput, NarikNgbInputDialog, NarikNgbInputModule, NarikNgbMessageDialog, NarikNgbRadioGroup, NarikNgbRadioGroupModule, NarikNgbSelect, NarikNgbSelectModule, NarikNgbTabOutlet, NarikNgbTabOutletModule, NarikNgbToolBar, NarikNgbToolbarModule, NarikNgbTreeview, NarikNgbTreeviewModule, NarikUiEditForm, NarikUiListForm, NarikUiNgBootstrapModule, NARIK_UI_COMPONENT_INPUTS as ɵa, NARIK_UI_FORM_INPUTS as ɵb, NARIK_DATA_ORIENTED_OUTPUTS as ɵc, NARIK_DATA_ORIENTED_INPUTS as ɵd, NARIK_DATA_DISPLAY_VALUE_OUTPUTS as ɵe, NARIK_DATA_DISPLAY_VALUE_INPUTS as ɵf, NARIK_CHECKBOX_INPUTS as ɵg, NARIK_SELECT_INPUTS as ɵh, NARIK_DATE_PICKER_INPUTS as ɵi, NARIK_INPUT_INPUTS as ɵj };
//# sourceMappingURL=narik-ui-ng-bootstrap.js.map
